<?php
/*
Nagios SmokePing Viewer
Version 1.0
---------------------
Bryan Heden
Agile Networks
---------------------
bheden@agilenetworks.com

This file is part of "Nagios SmokePing Viewer".

"Nagios SmokePing Viewer" is free software: you can redistribute it and/or modify
it under the terms of the GNU General Public License as published by
the Free Software Foundation, either version 3 of the License, or
(at your option) any later version.

"Nagios SmokePing Viewer" is distributed in the hope that it will be useful,
but WITHOUT ANY WARRANTY; without even the implied warranty of
MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
GNU General Public License for more details.

You should have received a copy of the GNU General Public License
along with "Nagios SmokePing Viewer".  If not, see <http://www.gnu.org/licenses/>.
*/

// include the component helper
require_once(dirname(__FILE__).'/../componenthelper.inc.php');

// initialization stuff
pre_init();

// start session
init_session();

// grab GET or POST variables 
grab_request_vars();

// check prereqs
check_prereqs();

// check authentication
check_authentication();

// route request / show page stuff
route_request();
function route_request() {
	global $request;
	show_page();
	exit;
}
function show_page($error = false, $msg = "") {
	global $request;
	global $lstr;
	
	////////////////////////////////////////////////
	// BEGIN CHANGABLE VARIABLES
	////////////////////////////////////////////////
	
	// the server url to curl
	$smokeping_url = "smokeping.aticus.agile";
	
	// an array of all of the targets we want
	$smokeping_targets = array('ZONE1', 'ZONE2', 'ZONE3');
	
	// do we show the full output or not?
	$smokeping_show_secondary_output = true;
	
	// the amount of time in seconds to display each image in the rotation placeholder before switching
	$smokeping_rotation_time = 3;
	
	// rotator image size (in pixels)
	$smokeping_rotator_img_size = 500;
	
	// full list (secondary) output img size (in pixels)
	$smokeping_full_list_img_size = 300;
	
	////////////////////////////////////////////////
	// END CHANGABLE VARIABLES
	////////////////////////////////////////////////
	
	// where all of the data is going to be held
	$smokeping_target_data = array();
	
	// final html output
	$smokeping_output = "";
	$smokeping_secondary_output = "";
	
	// javascript array
	$javascript_array = "[";
	
	// cycle through each target and get each one's full html
	foreach ($smokeping_targets as $smokeping_target) {
	
		// create curl resource 
		$ch = curl_init();

		// set url 
		curl_setopt($ch, CURLOPT_URL, "$smokeping_url/?target=$smokeping_target");

		//return the transfer as a string 
		curl_setopt($ch, CURLOPT_RETURNTRANSFER, 1);

		// $output contains the output string 
		$smokeping_target_data["$smokeping_target"] = curl_exec($ch);

		// close curl resource to free up system resources 
		curl_close($ch);
	}
	
	// change this around so that we can change the a href= links in the data
	$smokeping_url = (($_SERVER['HTTPS'] != "") ? "https://" : "http://") . $smokeping_url;

	// process the target data
	foreach ($smokeping_target_data as $target => $data) {
	
		// example output (the stuff we need to change):
		//<H1>Zone 1</H1>
		//<div><A HREF="?target=ZONE1.Zone1Gateway"><IMG BORDER="0" WIDTH="697" HEIGHT="138" SRC="../smokeping/img/ZONE1/Zone1Gateway_mini.png"></A></div>
	
		// trim our html down to what we really need (the block of html that contains the images)
		$data = substr($data, strpos($data, "</H1>"));
		$data = substr($data, 0, strpos($data, "</TD>"));
	
		// we don't need any of this stuff either
		$data = str_replace(array("<P>", "</P>", "</H1>", "WIDTH=\"697\"", "HEIGHT=\"138\"", "<div>", "</div>"), "", $data);
		
		// the smokeping links come back with ="?TARGET" ..we need to change the url here since we're linking from inside nagios
		// NOTE: the smokeping_url i use is a fully qualified domain name, so i don't use the smokeping.cgi that is used by default, you might want to change the
		//		/? in the next line to /smokeping.cgi? if you're unsure
		$data = str_replace("=\"?", "=\"$smokeping_url" . "/?", $data);
		
		// the smokeping images come back with ="../smokeping/img.." - we need to change that original ../smokeping to our location
		$data = str_replace("=\"../smokeping", "=\"$smokeping_url", $data);
		
		// append our processed data to the final output(s)
		$smokeping_output .= "<div class=\"target\" id=\"$target\">$data</div>";
		if ($smokeping_show_secondary_output)
			$smokeping_secondary_output .= "<div class=\"full_list\">$data</div>";
		
		// continue building the array that js will use
		$javascript_array .= "'$target', ";
	}
	
	// get the trailing comma and space and close the array
	$javascript_array = substr($javascript_array, 0, -2) . "];";
?>
<!DOCTYPE html>
<html>
<head>
	<title>Nagios XI - SmokePing</title>
	<meta name="viewport" content="initial-scale=1.0, user-scalable=no" />
	<meta name="ROBOTS" content="NOINDEX, NOFOLLOW">
	<meta http-equiv="Content-Type" content="text/html; charset=UTF-8" />
<?php do_page_head_links(); ?>
	<style type="text/css">
		img {
			width: <?php echo $smokeping_rotator_img_size; ?>px;
			display: block;
			float: left;
			padding: 10px;
		}
		.full_list img {
			width: <?php echo $smokeping_full_list_img_size; ?>px;
			padding: 5px;
			float: none;
		}
		.target {
			float: left;
			clear: left;
		}
		.full_list {
			float: left;
		}
		.invisible {
			display: none;
		}
		.clear {
			clear: both;
		}
	</style>
	<script type="text/javascript">
		var id_array = <?php echo $javascript_array; ?>
		window.setInterval(function() {
			$.each(id_array, function(key, val) {
				$('div#' + val + ' a:last').detach().insertBefore('div#' + val + ' a:nth-child(2)');
				$('div#' + val + ' a').addClass('invisible');
				$('div#' + val + ' a:first').removeClass('invisible');
				$('div#' + val + ' a:nth-child(2)').removeClass('invisible');
			});
		}, <?php echo ($smokeping_rotation_time * 1000); ?>);
	</script>
</head>
<body>
<?php 
	// output all of our processed target data
	echo $smokeping_output; ?>
	<div class="clear"></div>
<?php 
	// only if we have the variable set to show, do we show the second output (The full table of data, not just our rotating images)
	if ($smokeping_show_secondary_output)
		echo $smokeping_secondary_output; ?>
</body>
</html>
<?php
	exit();
}
?>